package compbio.ws.client;

import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.fail;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;
import javax.xml.ws.Service;

import org.testng.annotations.Test;

import compbio.data.msa.MsaWS;
import compbio.data.sequence.Alignment;
import compbio.data.sequence.FastaSequence;
import compbio.data.sequence.SequenceUtil;
import compbio.metadata.JobSubmissionException;
import compbio.metadata.LimitExceededException;
import compbio.metadata.ResultNotAvailableException;
import compbio.metadata.UnsupportedRuntimeException;
import compbio.util.SysPrefs;
import compbio.ws.server.ClustalWS;

public class TestWSClient {

	@Test
	public void test() throws FileNotFoundException, IOException {

		URL url = new URL("http://localhost:8080/jaba/ClustalWS?wsdl");
		String namespace = "http://msa.data.compbio/01/01/2010/";
		QName qname = new QName(namespace, "ClustalWS");
		Service serv = Service.create(url, qname);
		/*
		 * MsaWS msaws = serv.getPort(new QName(
		 * "http://msa.data.compbio/01/01/2010/", "ClustalWSPort"),
		 * MsaWS.class);
		 */
		// Annotation<AACon> msaws = serv.getPort(new QName(namespace,
		// "ClustalWSPort"), Annotation.class);

		MsaWS<ClustalWS> msaws = serv.getPort(new QName(namespace,
				"ClustalWSPort"), MsaWS.class);

		// List<FastaSequence> fsl = SequenceUtil.readFasta(new FileInputStream(
		// AAConTester.test_alignment_input));

		String CURRENT_DIRECTORY = SysPrefs.getCurrentDirectory()
				+ File.separator;

		List<FastaSequence> fsl = SequenceUtil.readFasta(new FileInputStream(
				CURRENT_DIRECTORY + "testsrc" + File.separator + "testdata"
						+ File.separator + "testlimit.in"));

		try {
			String jobId = msaws.align(fsl);
			Alignment result = msaws.getResult(jobId);
			assertNotNull(result);
			System.out.println(result);
		} catch (UnsupportedRuntimeException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (LimitExceededException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (JobSubmissionException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (ResultNotAvailableException e) {
			e.printStackTrace();
			fail(e.getMessage());
		}
		System.out.println("Pres: " + msaws.getPresets());
	}
}
